@@ -7,6 +7,8 @@
 #include <dballe/db/export.h>
 #include <dballe/msg/file.h>
 
+#include <stdlib.h>
+
 namespace dballe {
 
 Cursor::~Cursor()
@@ -50,6 +52,7 @@ bool Cursor::next(Record& rec)
 	checked(dba_db_cursor_next(m_cur, &has_data));
 	if (has_data)
 	{
+		dba_record_clear(rec.rec());
 		checked(dba_db_cursor_to_record(m_cur, rec.rec()));
 		return true;
 	} else
@@ -255,6 +258,24 @@ void DB::exportResultsAsGeneric(Record& query, dba_encoding encoding, const std:
 	dba_file_delete(out);
 }
 
+static dba_db test_db()
+{
+	dba_db db = NULL;
+	const char* dsn = getenv("DBA_TEST_DSN");
+	const char* user = getenv("DBA_TEST_USER");
+	const char* pass = getenv("DBA_TEST_PASS");
+	if (dsn == NULL || dsn[0] == 0) return db;
+	if (user == NULL) user = "";
+	if (pass == NULL) pass = "";
+
+	checked(dba_db_create(dsn, user, pass, &db));
+	return db;
+}
+
+TestDB::TestDB() : DB(test_db())
+{
+}
+
 }
 
 // vim:set ts=4 sw=4:
