@@ -1,7 +1,7 @@
 /*
  * DB-ALLe - Archive for punctual meteorological data
  *
- * Copyright (C) 2005,2006  ARPA-SIM <urpsim@smr.arpa.emr.it>
+ * Copyright (C) 2005--2008  ARPA-SIM <urpsim@smr.arpa.emr.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,16 @@ dba_err bufrex_msg_create(bufrex_type type, bufrex_msg* msg)
 	return dba_error_ok();
 }
 
-void bufrex_msg_reset(bufrex_msg msg)
+void bufrex_msg_reset_datadesc(bufrex_msg msg)
+{
+	if (msg->datadesc != NULL)
+	{
+		bufrex_opcode_delete(&(msg->datadesc));
+		msg->datadesc_last = &(msg->datadesc);
+	}
+}
+
+void bufrex_msg_reset_sections(bufrex_msg msg)
 {
 	int i;
 
@@ -50,12 +59,12 @@ void bufrex_msg_reset(bufrex_msg msg)
 	for (i = 0; i < msg->subsets_count; i++)
 		bufrex_subset_delete(msg->subsets[i]);
 	msg->subsets_count = 0;
+}
 
-	if (msg->datadesc != NULL)
-	{
-		bufrex_opcode_delete(&(msg->datadesc));
-		msg->datadesc_last = &(msg->datadesc);
-	}
+void bufrex_msg_reset(bufrex_msg msg)
+{
+	bufrex_msg_reset_sections(msg);
+	bufrex_msg_reset_datadesc(msg);
 
 	msg->type = 0;
 	msg->subtype = 0;
@@ -137,7 +146,17 @@ dba_err bufrex_msg_load_tables(bufrex_msg msg)
 							msg->opt.bufr.centre,
 							msg->opt.bufr.master_table,
 							msg->opt.bufr.local_table);
-						break;
+					/* Some tables used by BUFR3 are
+ 					 * distributed using BUFR4 names
+					 */
+					if (!dba_vartable_exists(id))
+						sprintf(id, "B00%03d%04d%04d%03d%03d",
+								0,
+								0,
+								msg->opt.bufr.centre,
+								msg->opt.bufr.master_table,
+								msg->opt.bufr.local_table);
+							break;
 				case 4:
 					sprintf(id, "B00%03d%04d%04d%03d%03d",
 							0,
@@ -179,15 +198,6 @@ dba_err bufrex_msg_query_dtable(bufrex_msg msg, dba_varcode code, struct _bufrex
 }
 
 
-void bufrex_msg_reset_datadesc(bufrex_msg msg)
-{
-	if (msg->datadesc != NULL)
-	{
-		bufrex_opcode_delete(&(msg->datadesc));
-		msg->datadesc_last = &(msg->datadesc);
-	}
-}
-
 dba_err bufrex_msg_get_datadesc(bufrex_msg msg, bufrex_opcode* res)
 {
 	*res = NULL;
