@@ -562,6 +562,44 @@ void to::test<21>()
 	//bufrex_msg_delete(msg1);
 }
 
+/*
+ * In this case, the ECMWF table has 12 bits for BUFR in Kelvin (up to 409.6)
+ * but 3 digits for CREX in Celsius (up to 99.0).  This means that BUFR can
+ * encode values too big to fit in CREX, and when it happens dba_var range
+ * checks kick in and abort decoding.
+ */
+template<> template<>
+void to::test<22>()
+{
+	/*
+	TestBufrexMsg test;
+	test.edition = 2;
+	test.cat = 6;
+	test.subcat = 255;
+	test.localsubcat = 0;
+	test.subsets = 1;
+	*/
+
+	bufrex_msg msg = read_test_msg_header_raw("bufr/crex-has-few-digits.bufr", BUFR);
+	/*
+	ensureBufrexRawEquals(test, msg);
+	ensure_equals(msg->rep_year, 2007);
+	ensure_equals(msg->rep_month, 8);
+	ensure_equals(msg->rep_day, 13);
+	ensure_equals(msg->rep_hour, 18);
+	ensure_equals(msg->rep_minute, 30);
+	ensure_equals(msg->rep_second, 0);
+
+	test.subset(0).vars = 4606;
+	*/
+
+	//bufrex_msg msg1 = reencode_test(msg);
+	//ensureBufrexRawEquals(test, msg1);
+
+	bufrex_msg_delete(msg);
+	//bufrex_msg_delete(msg1);
+}
+
 
 }
 
