@@ -25,6 +25,7 @@
 #include <stdio.h>
 #include <stdlib.h>		/* malloc, strtod, getenv */
 #include <string.h>		/* strncmp */
+#include <unistd.h>		/* access */
 #include <ctype.h>		/* isspace */
 #include <math.h>		/* rint */
 #include <assert.h>		/* assert */
@@ -51,7 +52,11 @@ static dba_vartable* tables = NULL;
 static int tables_size = 0;
 static int tables_alloc_size = 0;
 
-static dba_err dba_vartable_read(const char* id, int* index);
+#define VARTABLE_READ_DBALLE 0
+#define VARTABLE_READ_BUFR 1
+#define VARTABLE_READ_CREX 2
+
+static dba_err dba_vartable_read(const char* id, int* index, int style);
 
 /**
  * Insert a new vartable index in 'tables', keeping it sorted
@@ -146,8 +151,18 @@ dba_err dba_vartable_create(const char* id, dba_vartable* table)
 			begin = cur;
 	}
 	if (begin == -1 || strcmp(tables[begin]->id, id) != 0)
+	{
 		/* Table not found: load it */
-		DBA_RUN_OR_RETURN(dba_vartable_read(id, &begin));
+		if (strcmp(id, "dballe") == 0)
+			DBA_RUN_OR_RETURN(dba_vartable_read(id, &begin, VARTABLE_READ_DBALLE));
+		else {
+			size_t idlen = strlen(id);
+			if (idlen == 7)
+				DBA_RUN_OR_RETURN(dba_vartable_read(id, &begin, VARTABLE_READ_CREX));
+			else
+				DBA_RUN_OR_RETURN(dba_vartable_read(id, &begin, VARTABLE_READ_BUFR));
+		}
+	}
 
 	*table = tables[begin];
 
@@ -223,7 +238,10 @@ dba_err dba_vartable_query_altered(dba_vartable table, dba_varcode var, dba_alte
 			i->len = (int)ceil(log10(1 << i->bit_len));
 		}
 		if ((alt = DBA_ALT_SCALE(change)) != 0)
+		{
 			i->scale += alt;
+			i->bufr_scale += alt;
+		}
 
 #if 0
 		fprintf(stderr, "After alteration(w:%d,s:%d): bl %d len %d scale %d\n",
@@ -359,7 +377,13 @@ static dba_err vtb_new_entry(dba_vartable v, dba_varinfo* info)
 	return dba_error_ok();
 }
 
-static dba_err dba_vartable_read(const char* id, int* index)
+int dba_vartable_exists(const char* id)
+{
+	const char* file = id_to_pathname(id);
+	return access(file, F_OK) == 0;
+}
+
+static dba_err dba_vartable_read(const char* id, int* index, int style)
 {
 	dba_err err = DBA_OK;
 	dba_vartable vartable = NULL;
@@ -412,10 +436,12 @@ static dba_err dba_vartable_read(const char* id, int* index)
 		
 		/* Read the BUFR type */
 		memcpy(entry->unit, line+73, 24);
+		memcpy(entry->bufr_unit, line+73, 24);
 		/* Zero-terminate the type */
 		for (i = 23; i >= 0 && isspace(entry->unit[i]); i--)
 			;
 		entry->unit[i+1] = 0;
+		entry->bufr_unit[i+1] = 0;
 
 		entry->is_string = (
 				strcmp(entry->unit, "CCITTIA5") == 0 /*||
@@ -423,10 +449,11 @@ static dba_err dba_vartable_read(const char* id, int* index)
 		);
 
 		entry->scale = strtol(line+98, 0, 10);
+		entry->bufr_scale = strtol(line+98, 0, 10);
 		entry->bit_ref = strtol(line+102, 0, 10);
 		entry->bit_len = strtol(line+115, 0, 10);
 
-		if (strlen(line) < 157)
+		if (strlen(line) < 157 || style == VARTABLE_READ_BUFR)
 		{
 			entry->ref = 0;
 			if (entry->is_string)
