@@ -175,7 +175,12 @@ static dba_err decode_data_filter(const char* filter, dba_varinfo* info, const c
 			return dba_error_consistency("operator %.*s is not valid", len, filter + matches[2].rm_so);
 		memcpy(operator, filter + matches[2].rm_so, len);
 		operator[len] = 0;
-		*op = operator;
+		if (strcmp(operator, "!=") == 0)
+			*op = "<>";
+		else if (strcmp(operator, "==") == 0)
+			*op = "=";
+		else
+			*op = operator;
 
 		/* Parse the value */
 		DBA_RUN_OR_RETURN(parse_value(filter, matches[3], *info, value));
@@ -186,7 +191,7 @@ static dba_err decode_data_filter(const char* filter, dba_varinfo* info, const c
 	{
 		res = regexec(re_between, filter, 4, matches, 0);
 		if (res == REG_NOMATCH)
-			return dba_error_consistency("%s is not a valid filter");
+			return dba_error_consistency("%s is not a valid filter", filter);
 		if (res != 0)
 			return dba_error_regexp(res, re_normal, "Trying to parse '%s' as a 'between' filter", filter);
 		if (res == 0)
@@ -1077,7 +1082,8 @@ dba_err dba_db_cursor_query(dba_db_cursor cur, dba_record query, unsigned int wa
 		{
 			case MYSQL:
 				DBA_RUN_OR_RETURN(dba_querybuf_append(cur->query,
-					" GROUP BY d.id_var, d.id_context "
+					" GROUP BY d.id_var, c.id_ana, c.ltype1, c.l1, c.ltype2, c.l2,"
+                                        " c.ptype, c.p1, c.p2, c.datetime "
 					"HAVING ri.prio=MAX(ri.prio)"));
 				break;
 			case ORACLE:
@@ -1103,14 +1109,21 @@ dba_err dba_db_cursor_query(dba_db_cursor cur, dba_record query, unsigned int wa
 		} else if (cur->select_wanted & DBA_DB_FROM_C) {
 			if (cur->wanted & DBA_DB_WANT_ANA_ID)
 				DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "c.id_ana", &first));
+			if (cur->modifiers & DBA_DB_MODIFIER_SORT_FOR_EXPORT)
+				DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "c.id_report", &first));
 			if (cur->wanted & DBA_DB_WANT_DATETIME)
 				DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "c.datetime", &first));
 			if (cur->wanted & DBA_DB_WANT_LEVEL)
 				DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "c.ltype1, c.l1, c.ltype2, c.l2", &first));
 			if (cur->wanted & DBA_DB_WANT_TIMERANGE)
 				DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "c.ptype, c.p1, c.p2", &first));
-			if (cur->select_wanted & DBA_DB_FROM_RI)
-				DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "ri.prio", &first));
+			if (!(cur->modifiers & DBA_DB_MODIFIER_SORT_FOR_EXPORT) && (cur->wanted & DBA_DB_WANT_REPCOD))
+			{
+				if (cur->select_wanted & DBA_DB_FROM_RI)
+					DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "ri.prio", &first));
+				else 
+					DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "c.id_report", &first));
+			}
 		} else if (cur->select_wanted & DBA_DB_FROM_PA) {
 			if (cur->wanted & DBA_DB_WANT_ANA_ID)
 				DBA_RUN_OR_RETURN(add_to_orderby(cur->query, "pa.id", &first));
@@ -1183,17 +1196,8 @@ static dba_err dba_ana_add_extra(dba_db_cursor cur, dba_record rec)
 	 * BLOCK,       B01001   257
 	 * STATION,     B01002   258
 	*/
-	const char* query =
-		"SELECT d.id_var, d.value, ri.id, ri.prio"
-		"  FROM context c, data d, repinfo ri"
-		" WHERE c.id = d.id_context AND ri.id = c.id_report AND c.id_ana = ?"
-		"   AND c.datetime = {ts '1000-01-01 00:00:00.0'}"
-		"   AND c.ltype1 = 257 AND c.l1 = 0 AND c.ltype2 = 0 AND c.l2 = 0"
-		"   AND c.ptype = 0 AND c.p1 = 0 AND c.p2 = 0"
-		" GROUP BY d.id_var,ri.id "
-		"HAVING ri.prio=MAX(ri.prio)";
-
 	dba_err err = DBA_OK;
+	const char* query;
 	SQLHSTMT stm;
 	int res;
 	dba_db db = cur->db;
@@ -1202,6 +1206,34 @@ static dba_err dba_ana_add_extra(dba_db_cursor cur, dba_record rec)
 	SQLLEN out_val_ind;
 	DBALLE_SQL_C_SINT_TYPE out_rep_cod;
 
+#define BASE_QUERY \
+		"SELECT d.id_var, d.value, ri.id, ri.prio" \
+		"  FROM context c, data d, repinfo ri" \
+		" WHERE c.id = d.id_context AND ri.id = c.id_report AND c.id_ana = ?" \
+		"   AND c.datetime = {ts '1000-01-01 00:00:00.0'}" \
+		"   AND c.ltype1 = 257 AND c.l1 = 0 AND c.ltype2 = 0 AND c.l2 = 0" \
+		"   AND c.ptype = 0 AND c.p1 = 0 AND c.p2 = 0"
+
+	switch (cur->db->server_type)
+	{
+		case MYSQL:
+			query = BASE_QUERY
+				" GROUP BY d.id_var,ri.id "
+				"HAVING ri.prio=MAX(ri.prio)";
+			break;
+		default:
+			query = BASE_QUERY
+				" AND ri.prio=("
+				"  SELECT MAX(sri.prio) FROM repinfo sri"
+				"    JOIN context sc ON sri.id=sc.id_report"
+				"    JOIN data sd ON sc.id=sd.id_context"
+				"  WHERE sc.id_ana=c.id_ana"
+				"    AND sc.ltype1=c.ltype1 AND sc.l1=c.l1 AND sc.ltype2=c.ltype2 AND sc.l2=c.l2"
+				"    AND sc.ptype=c.ptype AND sc.p1=c.p1 AND sc.p2=c.p2"
+				"    AND sc.datetime=c.datetime AND sd.id_var=d.id_var)";
+			break;
+	}
+#undef BASE_QUERY
 
 	/* Allocate statement handle */
 	DBA_RUN_OR_RETURN(dba_db_statement_create(db, &stm));
