@@ -20,6 +20,7 @@
  */
 
 #include "test-utils-db.h"
+#include <dballe/db/internals.h>
 
 #include <unistd.h>
 #include <sys/types.h>
@@ -27,7 +28,7 @@
 
 namespace tut_dballe {
 
-dba_err create_dba_db(dba_db* db)
+db_test::db_test() : db(NULL)
 {
 /*
 	const char* uname = getenv("DBA_USER");
@@ -37,7 +38,28 @@ dba_err create_dba_db(dba_db* db)
 		uname = pwd == NULL ? "test" : pwd->pw_name;
 	}
 */
-	return dba_db_create("test", "" , "", db);
+	const char* dsn = getenv("DBA_TEST_DSN");
+	const char* user = getenv("DBA_TEST_USER");
+	const char* pass = getenv("DBA_TEST_PASS");
+	if (dsn == NULL) return;
+	if (user == NULL) user = "";
+	if (pass == NULL) pass = "";
+
+	CHECKED(dba_db_create(dsn, user, pass, &db));
+	CHECKED(dba_db_reset(db, NULL));
+}
+db_test::~db_test()
+{
+	if (db != NULL)
+	{
+		CHECKED(dba_db_commit(db));
+		dba_db_delete(db);
+	}
+}
+void db_test::use_db()
+{
+	if (db == NULL)
+		throw tut::no_such_test();
 }
 
 }
