@@ -26,21 +26,16 @@
 namespace tut {
 using namespace tut_dballe;
 
-struct db_import_shar
+struct db_import_shar : public db_test
 {
 	TestMsgEnv testenv;
 
-	// DB handle
-	dba_db db;
-
-	db_import_shar() : db(NULL)
+	db_import_shar()
 	{
-		CHECKED(create_dba_db(&db));
 	}
 
 	~db_import_shar()
 	{
-		if (db != NULL) dba_db_delete(db);
 		test_untag();
 	}
 };
@@ -68,9 +63,19 @@ static dba_err msg_collector(dba_msgs msgs, void* data)
 	return dba_error_ok();
 }
 
+static dba_err msgs_collector(dba_msgs msgs, void* data)
+{
+//	cerr << "MSG COLLECTOR";
+	msg_vector* vec = static_cast<msg_vector*>(data);
+	vec->push_back(msgs);
+	return dba_error_ok();
+}
+
 template<> template<>
 void to::test<1>()
 {
+	use_db();
+
 	const char* files[] = {
 		"crex/test-mare0.crex",
 		"crex/test-mare1.crex",
@@ -124,6 +129,8 @@ void to::test<1>()
 template<> template<>
 void to::test<2>()
 {
+	use_db();
+
 	const char* files[] = {
 		"bufr/obs0-1.22.bufr", 
 		"bufr/obs0-1.11188.bufr", 
@@ -194,6 +201,8 @@ void to::test<2>()
 template<> template<>
 void to::test<3>()
 {
+	use_db();
+
 	const char* files[] = {
 		"aof/obs1-14.63.aof",
 		"aof/obs1-21.1.aof",
@@ -253,6 +262,8 @@ void to::test<3>()
 template<> template<>
 void to::test<4>()
 {
+	use_db();
+
 	// msg1 has latitude 33.88
 	// msg2 has latitude 46.22
 	dba_msgs msgs1 = read_test_msg("bufr/obs0-1.22.bufr", BUFR);
@@ -301,6 +312,8 @@ void to::test<4>()
 template<> template<>
 void to::test<5>()
 {
+	use_db();
+
 	msg_generator gen;
 
 	CHECKED(dba_db_reset(db, NULL));
@@ -347,6 +360,8 @@ static dba_err msg_counter(dba_msgs msgs, void* data)
 template<> template<>
 void to::test<6>()
 {
+	use_db();
+
 	msg_vector msgs;
 
 	// All the various input messages with unique data
@@ -415,6 +430,184 @@ void to::test<6>()
 	test_untag();
 }
 
+static void clear_datetime_attrs(dba_msg msg)
+{
+	for (int i = 0; i < msg->data_count; i++)
+	{
+		dba_msg_level lev = msg->data[i];
+		if (lev->ltype1 != 257) continue;
+		for (int j = 0; j < lev->data_count; j++)
+		{
+			dba_msg_datum dat = lev->data[j];
+			if (DBA_VAR_X(dba_var_code(dat->var)) != 4) continue;
+			dba_var_clear_attrs(dat->var);
+		}
+    }
+}
+
+// Check a case when two AOF messages cannot be exported after import
+template<> template<>
+void to::test<7>()
+{
+	use_db();
+
+	msg_vector msgs;
+	const char* fname = "aof/err1.aof";
+
+	CHECKED(read_file(AOF, fname, msgs));
+
+	CHECKED(dba_db_reset(db, NULL));
+
+	//map<dba_msg_type, int> rep_cods;
+	for (msg_vector::const_iterator i = msgs.begin(); i != msgs.end(); i++)
+	{
+		CHECKED(dba_import_msgs(db, *i, -1, DBA_IMPORT_ATTRS));
+		//rep_cods[(*i)->msgs[0]->type]++;
+	}
+
+	dba_record query;
+	CHECKED(dba_record_create(&query));
+	msg_vector msgs1;
+	CHECKED(dba_db_export(db, query, msgs_collector, &msgs1));
+	gen_ensure_equals(msgs1.size(), 2u);
+
+	clear_datetime_attrs(msgs[0]->msgs[0]);
+	clear_datetime_attrs(msgs[1]->msgs[0]);
+
+	#if 0
+	fprintf(stderr, "msgs[0]\n");
+	dba_msg_print(msgs[0]->msgs[0], stderr);
+	fprintf(stderr, "msgs[1]\n");
+	dba_msg_print(msgs[1]->msgs[0], stderr);
+	fprintf(stderr, "msgs1[0]\n");
+	dba_msg_print(msgs1[0]->msgs[0], stderr);
+	fprintf(stderr, "msgs1[1]\n");
+	dba_msg_print(msgs1[1]->msgs[0], stderr);
+	#endif
+
+	#if 0
+	// Compare the two dba_msg
+	int diffs = 0;
+	dba_msg_diff(msgs[0]->msgs[0], msgs1[0]->msgs[0], &diffs, stderr);
+	if (diffs != 0) track_different_msgs(msgs[0], msgs1[0], "aof-reexported1");
+	gen_ensure_equals(diffs, 0);
+
+	diffs = 0;
+	dba_msg_diff(msgs[1]->msgs[0], msgs1[1]->msgs[0], &diffs, stderr);
+	if (diffs != 0) track_different_msgs(msgs[1], msgs1[1], "aof-reexported2");
+	gen_ensure_equals(diffs, 0);
+	#endif
+
+	dba_rawmsg rmsg;
+	CHECKED(dba_marshal_encode(msgs[0], BUFR, &rmsg));
+	dba_rawmsg_delete(rmsg);
+	CHECKED(dba_marshal_encode(msgs[1], BUFR, &rmsg));
+	dba_rawmsg_delete(rmsg);
+	CHECKED(dba_marshal_encode(msgs1[0], BUFR, &rmsg));
+	dba_rawmsg_delete(rmsg);
+	CHECKED(dba_marshal_encode(msgs1[1], BUFR, &rmsg));
+	dba_rawmsg_delete(rmsg);
+
+
+	dba_record_delete(query);
+
+
+	#if 0
+	dba_record query;
+	CHECKED(dba_record_create(&query));
+	for (map<dba_msg_type, int>::const_iterator i = rep_cods.begin(); i != rep_cods.end(); i++)
+	{
+		test_tag(dba_msg_type_name(i->first));
+
+		int count = 0;
+		CHECKED(dba_record_key_seti(query, DBA_KEY_REP_COD, dba_msg_repcod_from_type(i->first)));
+		CHECKED(dba_db_export(db, query, msg_counter, &count));
+		gen_ensure_equals(count, i->second);
+	}
+	#endif
+}
+
+// Check a case when two messages imported get mangled and export exports
+// different messages
+template<> template<>
+void to::test<8>()
+{
+	use_db();
+
+	msg_vector msgs;
+	const char* fname = "bufr/synotemp.bufr";
+
+	CHECKED(read_file(BUFR, fname, msgs));
+
+	CHECKED(dba_db_reset(db, NULL));
+
+	//map<dba_msg_type, int> rep_cods;
+	for (msg_vector::const_iterator i = msgs.begin(); i != msgs.end(); i++)
+	{
+		CHECKED(dba_import_msgs(db, *i, -1, DBA_IMPORT_ATTRS | DBA_IMPORT_FULL_PSEUDOANA | DBA_IMPORT_DATETIME_ATTRS));
+		//rep_cods[(*i)->msgs[0]->type]++;
+	}
+
+	dba_record query;
+	CHECKED(dba_record_create(&query));
+	msg_vector msgs1;
+	CHECKED(dba_db_export(db, query, msgs_collector, &msgs1));
+	gen_ensure_equals(msgs1.size(), 2u);
+
+	//clear_datetime_attrs(msgs[0]->msgs[0]);
+	//clear_datetime_attrs(msgs[1]->msgs[0]);
+
+	#if 0
+	fprintf(stderr, "msgs[0]\n");
+	dba_msg_print(msgs[0]->msgs[0], stderr);
+	fprintf(stderr, "msgs[1]\n");
+	dba_msg_print(msgs[1]->msgs[0], stderr);
+	fprintf(stderr, "msgs1[0]\n");
+	dba_msg_print(msgs1[0]->msgs[0], stderr);
+	fprintf(stderr, "msgs1[1]\n");
+	dba_msg_print(msgs1[1]->msgs[0], stderr);
+	#endif
+
+	// Compare the two dba_msg
+	int diffs = 0;
+	dba_msg_diff(msgs[0]->msgs[0], msgs1[1]->msgs[0], &diffs, stderr);
+	if (diffs != 0) track_different_msgs(msgs[0], msgs1[1], "synotemp-reexported1");
+	gen_ensure_equals(diffs, 0);
+
+	diffs = 0;
+	dba_msg_diff(msgs[1]->msgs[0], msgs1[0]->msgs[0], &diffs, stderr);
+	if (diffs != 0) track_different_msgs(msgs[1], msgs1[0], "synotemp-reexported2");
+	gen_ensure_equals(diffs, 0);
+
+	//dba_rawmsg rmsg;
+	//CHECKED(dba_marshal_encode(msgs[0], BUFR, &rmsg));
+	//dba_rawmsg_delete(rmsg);
+	//CHECKED(dba_marshal_encode(msgs[1], BUFR, &rmsg));
+	//dba_rawmsg_delete(rmsg);
+	//CHECKED(dba_marshal_encode(msgs1[0], BUFR, &rmsg));
+	//dba_rawmsg_delete(rmsg);
+	//CHECKED(dba_marshal_encode(msgs1[1], BUFR, &rmsg));
+	//dba_rawmsg_delete(rmsg);
+
+
+	dba_record_delete(query);
+
+
+	#if 0
+	dba_record query;
+	CHECKED(dba_record_create(&query));
+	for (map<dba_msg_type, int>::const_iterator i = rep_cods.begin(); i != rep_cods.end(); i++)
+	{
+		test_tag(dba_msg_type_name(i->first));
+
+		int count = 0;
+		CHECKED(dba_record_key_seti(query, DBA_KEY_REP_COD, dba_msg_repcod_from_type(i->first)));
+		CHECKED(dba_db_export(db, query, msg_counter, &count));
+		gen_ensure_equals(count, i->second);
+	}
+	#endif
+}
+
 }
 
 // vim:set ts=4 sw=4:
