@@ -53,6 +53,15 @@ dba_err bufrex_copy_to_generic(dba_msg msg, bufrex_msg raw, bufrex_subset sset)
 			case DBA_VAR(0, 7, 193): DBA_RUN_OR_GOTO(cleanup, dba_var_enqi(var, &l1)); break;
 			case DBA_VAR(0, 7, 194): DBA_RUN_OR_GOTO(cleanup, dba_var_enqi(var, &l2)); break;
 			case DBA_VAR(0, 7, 195): DBA_RUN_OR_GOTO(cleanup, dba_var_enqi(var, &ltype2)); break;
+			case DBA_VAR(0, 1, 193):
+			{
+				// Set the repcod if we found it
+				int rc;
+				DBA_RUN_OR_GOTO(cleanup, dba_var_enqi(var, &rc));
+				msg->type = dba_msg_type_from_repcod(rc);
+				DBA_RUN_OR_GOTO(cleanup, dba_msg_set_rep_cod(msg, rc, -1));
+				break;
+			}
 			default:
 				if (ltype1 == -1 || l1 == -1 || ltype2 == -1 || l2 == -1 || pind == -1 || p1 == -1 || p2 == -1)
 					DBA_FAIL_GOTO(cleanup, dba_error_consistency(
