@@ -1,7 +1,7 @@
 /*
  * DB-ALLe - Archive for punctual meteorological data
  *
- * Copyright (C) 2005,2006  ARPA-SIM <urpsim@smr.arpa.emr.it>
+ * Copyright (C) 2005--2008  ARPA-SIM <urpsim@smr.arpa.emr.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -86,7 +86,8 @@ enum _dba_msg_type {
 	MSG_SHIP,		/**< Ship measured data */
 	MSG_BUOY,		/**< Buoy measured data */
 	MSG_METAR,		/**< Metar data */
-	MSG_SAT			/**< Satellite data */
+	MSG_SAT,		/**< Satellite data */
+	MSG_POLLUTION	/**< Pollution data */
 };
 /** @copydoc _dba_msg_type */
 typedef enum _dba_msg_type dba_msg_type;
@@ -181,10 +182,12 @@ void dba_msg_delete(dba_msg msg);
  * @param code
  *   The dba_varcode of the destination value.  If it is different than the
  *   varcode of var, a conversion will be attempted.
- * @param ltype
- *   Type of the level.  See @ref level_table.
+ * @param ltype1
+ *   Type of the first level.  See @ref level_table.
  * @param l1
  *   L1 value of the level.  See @ref level_table.
+ * @param ltype2
+ *   Type of the second level.  See @ref level_table.
  * @param l2
  *   L2 value of the level.  See @ref level_table.
  * @param pind
@@ -196,7 +199,7 @@ void dba_msg_delete(dba_msg msg);
  * @return
  *   The error indicator for the function (See @ref error.h)
  */
-dba_err dba_msg_set(dba_msg msg, dba_var var, dba_varcode code, int ltype, int l1, int l2, int pind, int p1, int p2);
+dba_err dba_msg_set(dba_msg msg, dba_var var, dba_varcode code, int ltype1, int l1, int ltype2, int l2, int pind, int p1, int p2);
 
 /**
  * Add or replace a value in the dba_msg, taking ownership of the source
@@ -222,7 +225,7 @@ dba_err dba_msg_set(dba_msg msg, dba_var var, dba_varcode code, int ltype, int l
  * @return
  *   The error indicator for the function (See @ref error.h)
  */
-dba_err dba_msg_set_nocopy(dba_msg msg, dba_var var, int ltype, int l1, int l2, int pind, int p1, int p2);
+dba_err dba_msg_set_nocopy(dba_msg msg, dba_var var, int ltype1, int l1, int ltype2, int l2, int pind, int p1, int p2);
 
 /**
  * Add or replace a value in the dba_msg
@@ -266,7 +269,7 @@ dba_err dba_msg_set_nocopy_by_id(dba_msg msg, dba_var var, int id);
  * @param conf
  *   The confidence interval of the data, as the value of a B33007 WMO B (per
  *   cent confidence) table entry, that is, a number between 0 and 100
- *   inclusive.
+ *   inclusive.  -1 means no confidence interval attribute.
  * @param ltype
  *   Type of the level.  See @ref level_table.
  * @param l1
@@ -282,7 +285,7 @@ dba_err dba_msg_set_nocopy_by_id(dba_msg msg, dba_var var, int id);
  * @return
  *   The error indicator for the function (See @ref error.h)
  */
-dba_err dba_msg_seti(dba_msg msg, dba_varcode code, int val, int conf, int ltype, int l1, int l2, int pind, int p1, int p2);
+dba_err dba_msg_seti(dba_msg msg, dba_varcode code, int val, int conf, int ltype1, int l1, int ltype2, int l2, int pind, int p1, int p2);
 
 /**
  * Add or replace a double value in the dba_msg
@@ -296,7 +299,7 @@ dba_err dba_msg_seti(dba_msg msg, dba_varcode code, int val, int conf, int ltype
  * @param conf
  *   The confidence interval of the data, as the value of a B33007 WMO B (per
  *   cent confidence) table entry, that is, a number between 0 and 100
- *   inclusive.
+ *   inclusive.  -1 means no confidence interval attribute.
  * @param ltype
  *   Type of the level.  See @ref level_table.
  * @param l1
@@ -312,7 +315,7 @@ dba_err dba_msg_seti(dba_msg msg, dba_varcode code, int val, int conf, int ltype
  * @return
  *   The error indicator for the function (See @ref error.h)
  */
-dba_err dba_msg_setd(dba_msg msg, dba_varcode code, double val, int conf, int ltype, int l1, int l2, int pind, int p1, int p2);
+dba_err dba_msg_setd(dba_msg msg, dba_varcode code, double val, int conf, int ltype1, int l1, int ltype2, int l2, int pind, int p1, int p2);
 
 /**
  * Add or replace a string value in the dba_msg
@@ -326,7 +329,7 @@ dba_err dba_msg_setd(dba_msg msg, dba_varcode code, double val, int conf, int lt
  * @param conf
  *   The confidence interval of the data, as the value of a B33007 WMO B (per
  *   cent confidence) table entry, that is, a number between 0 and 100
- *   inclusive.
+ *   inclusive.  -1 means no confidence interval attribute.
  * @param ltype
  *   Type of the level.  See @ref level_table.
  * @param l1
@@ -342,7 +345,7 @@ dba_err dba_msg_setd(dba_msg msg, dba_varcode code, double val, int conf, int lt
  * @return
  *   The error indicator for the function (See @ref error.h)
  */
-dba_err dba_msg_setc(dba_msg msg, dba_varcode code, const char* val, int conf, int ltype, int l1, int l2, int pind, int p1, int p2);
+dba_err dba_msg_setc(dba_msg msg, dba_varcode code, const char* val, int conf, int ltype1, int l1, int ltype2, int l2, int pind, int p1, int p2);
 
 
 /**
@@ -359,7 +362,7 @@ dba_err dba_msg_setc(dba_msg msg, dba_varcode code, const char* val, int conf, i
  * @return
  *   The level found, or NULL if it was not found.
  */
-dba_msg_level dba_msg_find_level(dba_msg msg, int ltype, int l1, int l2);
+dba_msg_level dba_msg_find_level(dba_msg msg, int ltype1, int l1, int ltype2, int l2);
 
 /**
  * Find a datum given its description
@@ -383,7 +386,7 @@ dba_msg_level dba_msg_find_level(dba_msg msg, int ltype, int l1, int l2);
  * @return
  *   The level found, or NULL if it was not found.
  */
-dba_msg_datum dba_msg_find(dba_msg msg, dba_varcode code, int ltype, int l1, int l2, int pind, int p1, int p2);
+dba_msg_datum dba_msg_find(dba_msg msg, dba_varcode code, int ltype1, int l1, int ltype2, int l2, int pind, int p1, int p2);
 
 /** 
  * Find a datum given its shortcut ID
