@@ -1,7 +1,7 @@
 /*
  * DB-ALLe - Archive for punctual meteorological data
  *
- * Copyright (C) 2005,2008  ARPA-SIM <urpsim@smr.arpa.emr.it>
+ * Copyright (C) 2005--2008  ARPA-SIM <urpsim@smr.arpa.emr.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,6 +58,12 @@ void to::test<1>()
 		"aof/obs5-36.30.aof",
 		"aof/obs6-32.1573.aof",
 		"aof/obs6-32.0.aof",
+		"aof/aof_27-2-144.aof",
+		"aof/aof_28-2-144.aof",
+		"aof/aof_27-2-244.aof",
+		"aof/aof_28-2-244.aof",
+		"aof/missing-cloud-h.aof",
+		"aof/brokenamdar.aof",
 		NULL,
 	};
 
@@ -189,7 +195,22 @@ void normalise_encoding_quirks(dba_msgs amsgs, dba_msgs bmsgs)
 		// AOF AMDAR has pressure indication, BUFR AMDAR has only height
 		if (amsg->type == MSG_AMDAR)
 		{
-			dba_var p = dba_msg_get_flight_press_var(amsg);
+			// dba_var p = dba_msg_get_flight_press_var(amsg);
+			for (int i = 0; i < amsg->data_count; ++i)
+			{
+				dba_msg_level l = amsg->data[i];
+				if (l->ltype1 == 100)
+				{
+					dba_msg_datum datum = dba_msg_level_find(l, DBA_VAR(0, 10, 4), 254, 0, 0);
+					if (datum)
+					{
+						CHECKED(dba_msg_set(bmsg, datum->var, DBA_VAR(0, 10, 4),
+							l->ltype1, l->l1, l->ltype2, l->l2,
+							254, 0, 0));
+						break;
+					}
+				}
+			}
 #if 0
 			dba_var h = dba_msg_get_height_var(bmsg);
 			if (p && h)
@@ -206,8 +227,6 @@ void normalise_encoding_quirks(dba_msgs amsgs, dba_msgs bmsgs)
 				}
 			}
 #endif
-			if (p)
-				CHECKED(dba_msg_set_flight_press_var(bmsg, p));
 		}
 
 		if (amsg->type == MSG_TEMP)
@@ -348,6 +367,10 @@ void to::test<2>()
 		"aof/obs5-36.30.aof",
 		"aof/obs6-32.1573.aof",
 		"aof/obs6-32.0.aof",
+		"aof/aof_27-2-144.aof",
+		"aof/aof_28-2-144.aof",
+		"aof/aof_27-2-244.aof",
+		"aof/aof_28-2-244.aof",
 		NULL,
 	};
 
@@ -396,6 +419,10 @@ void to::test<3>()
 		"aof/obs5-36.30.aof",
 		"aof/obs6-32.1573.aof",
 		"aof/obs6-32.0.aof",
+		"aof/aof_27-2-144.aof",
+		"aof/aof_28-2-144.aof",
+		"aof/aof_27-2-244.aof",
+		"aof/aof_28-2-244.aof",
 		NULL,
 	};
 
@@ -467,6 +494,70 @@ void to::test<4>()
 	test_untag();
 }
 
+// Compare no-dew-point AOF plane reports with those with dew point
+template<> template<>
+void to::test<5>()
+{
+	string prefix = "aof/aof_";
+	const char* files[] = {
+		"-2-144.aof",
+		"-2-244.aof",
+		NULL,
+	};
+
+	for (size_t i = 0; files[i] != NULL; i++)
+	{
+		test_tag(prefix + "2x" + files[i]);
+
+		dba_msgs amsgs1 = read_test_msg((prefix + "27" + files[i]).c_str(), AOF);
+		dba_msgs amsgs2 = read_test_msg((prefix + "28" + files[i]).c_str(), AOF);
+		
+		// Compare the two dba_msg
+		int diffs = 0;
+		dba_msgs_diff(amsgs1, amsgs2, &diffs, stderr);
+		if (diffs) track_different_msgs(amsgs1, amsgs2, "aof-2728");
+		gen_ensure_equals(diffs, 0);
+
+		dba_msgs_delete(amsgs1);
+		dba_msgs_delete(amsgs2);
+	}
+	test_untag();
+}
+
+// Ensure that missing values in existing synop optional sections are caught
+// correctly
+template<> template<>
+void to::test<6>()
+{
+	dba_msgs msgs = read_test_msg("aof/missing-cloud-h.aof", AOF);
+	gen_ensure_equals(msgs->len, 1);
+
+	dba_msg msg = msgs->msgs[0];
+	gen_ensure_equals(dba_msg_get_cloud_h1_var(msg), (dba_var)NULL);
+
+	dba_msgs_delete(msgs);
+}
+
+// Verify decoding of confidence intervals in optional ship group
+template<> template<>
+void to::test<7>()
+{
+	dba_msgs msgs = read_test_msg("aof/confship.aof", AOF);
+	gen_ensure_equals(msgs->len, 1);
+
+	dba_msg msg = msgs->msgs[0];
+	dba_var var = dba_msg_get_st_dir_var(msg);
+	gen_ensure(var != NULL);
+	dba_var attr;
+	CHECKED(dba_var_enqa(var, DBA_VAR(0, 33, 7), &attr));
+	gen_ensure(attr != NULL);
+	int ival;
+	CHECKED(dba_var_enqi(attr, &ival));
+	ensure_equals(ival, 51);
+
+	dba_msgs_delete(msgs);
+}
+
 #if 0
 	CHECKED(dba_aof_decoder_start(decoder, "test-aof-01"));
 	while (1)
