@@ -69,7 +69,7 @@ from datetime import *
 import os
 if os.environ.get("DBALLE_BUILDING_DOCS", "") != 'true':
 	import numpy
-	import numpy.core.ma as ma
+	import numpy.ma as ma
 
 
 class SkipDatum(Exception): pass
